@@ -10,23 +10,25 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.04';
-$DATE = '2003/09/19';
+$VERSION = '0.05';
+$DATE = '2004/05/04';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/Text_Replace.pm' => [qw(0.04 2003/09/19), 'revised 0.03'],
-    'MANIFEST' => [qw(0.04 2003/09/19), 'generated, replaces 0.03'],
-    'Makefile.PL' => [qw(0.04 2003/09/19), 'generated, replaces 0.03'],
-    'README' => [qw(0.04 2003/09/19), 'generated, replaces 0.03'],
-    'lib/Text/Replace.pm' => [qw(1.1 2003/09/19), 'revised 1.09'],
-    't/Text/Replace.t' => [qw(0.04 2003/09/15), 'unchanged'],
-    't/Text/Replace.pm' => [qw(0.01 2003/07/05), 'unchanged'],
-    't/Text/Replace.d' => [qw(0.01 2003/07/27), 'unchanged'],
-    'tlib/File/Package.pm' => [qw(1.12 2003/09/19), 'unchanged'],
-    'tlib/Test/Tech.pm' => [qw(1.14 2003/09/19), 'revised 1.13'],
-    'tlib/Data/Secs2.pm' => [qw(1.14 2003/09/19), 'new'],
+    'lib/Docs/Site_SVD/Text_Replace.pm' => [qw(0.05 2004/05/04), 'revised 0.04'],
+    'MANIFEST' => [qw(0.05 2004/05/04), 'generated, replaces 0.04'],
+    'Makefile.PL' => [qw(0.05 2004/05/04), 'generated, replaces 0.04'],
+    'README' => [qw(0.05 2004/05/04), 'generated, replaces 0.04'],
+    'lib/Text/Replace.pm' => [qw(1.11 2004/05/04), 'revised 1.1'],
+    't/Text/Replace.t' => [qw(0.05 2004/05/04), 'revised 0.04'],
+    't/Text/Replace.pm' => [qw(0.03 2004/05/04), 'revised 0.02'],
+    't/Text/Replace.d' => [qw(0.04 2004/05/04), 'revised 0.03'],
+    't/Text/File/Package.pm' => [qw(1.16 2004/05/04), 'new'],
+    't/Text/Test/Tech.pm' => [qw(1.22 2004/05/04), 'new'],
+    't/Text/Data/Secs2.pm' => [qw(1.19 2004/05/04), 'new'],
+    't/Text/Data/SecsPack.pm' => [qw(0.04 2004/05/04), 'new'],
+    't/Text/Data/Startup.pm' => [qw(0.04 2004/05/04), 'new'],
 
 );
 
@@ -53,11 +55,11 @@ use vars qw(%INVENTORY);
 
  Text::Replace - Replace variables in templates
 
- Revision: C
+ Revision: D
 
- Version: 0.04
+ Version: 0.05
 
- Date: 2003/09/19
+ Date: 2004/05/04
 
  Prepared for: General Public 
 
@@ -81,34 +83,31 @@ extend the capabilities of the Perl language.
 
 =head2 1.2 System overview
 
-The "L<Text::Replace|Text::Replace>" module, 
-extends the Perl language (the system).
+The C<Text::Replace> program module is simple and plain. 
+This is intentional. The C<Text::Replace> mimics the
+built-in Perl double quote, '"', literal scalar that
+replaces Perl scalar variables named with a leading '$'.
+The C<Text::Replace> program module foregoes 
+expressiveness for convenience and performance.
+Like a movie score, it stays in the background.
+There is no large manual thicker than the Bible 
+with tricks and tips and gyrations to learn and 
+to distract.
+It is amazing how many times, just a simple double quote
+literal replacement in a small text string or even a
+large text string gets the job done.
 
-The US DOD 2167A software development standard creates and cites a
-fully decent number of Data Item Descriptions (DID). 
-A DID and US DOD 490A, Specification Practices, specify in
-great detail the paragraph number, headings and the information
-required for each paragraph in the document govern by the DID.
-
-The usually approach is for suppliers of the DIDs to set up templates
-and fill in the template with the missing information to complete the
-DID document.
-
-Different organizations use different degrees of automation. 
-Some will have hard copy templates. Some will use word processor
-templates. Others will use Visual Basic to merge database information
-into a template. 
-
-The methods in this module support a Perl automation of this processes
-by merging a hash of variables with a template.
-
-Replacement of variables in a template has many others uses beside
-filling out technical document templates such as merging mailing list
-with emails or form letters.
+Does C<Text::Replace> solve all variable replacement, template
+problems? Definitely not.
+There is no capabilities for inserting graphs, text wrap plug-ins,
+GD interface.
+If an application needs something this sophisticated,
+there are many fine template program modules in CPAN
+such as the highly rated C<Template> program module.
 
 =head2 1.3 Document overview.
 
-This document releases Text::Replace version 0.04
+This document releases Text::Replace version 0.05
 providing a description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -121,12 +120,14 @@ system file specification.
 
 =head2 3.1 Inventory of materials released.
 
-This document releases the file found
-at the following repository(s):
+This document releases the file 
 
-   http://www.softwarediamonds/packages/Text-Replace-0.04
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Text-Replace-0.04
+ Text-Replace-0.05.tar.gz
 
+found at the following repository(s):
+
+  http://www.softwarediamonds/packages/
+  http://www.perl.com/CPAN/authors/id/S/SO/SOFTDIA/
 
 Restrictions regarding duplication and license provisions
 are as follows:
@@ -193,17 +194,19 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/Text_Replace.pm                            0.04    2003/09/19 revised 0.03
- MANIFEST                                                     0.04    2003/09/19 generated, replaces 0.03
- Makefile.PL                                                  0.04    2003/09/19 generated, replaces 0.03
- README                                                       0.04    2003/09/19 generated, replaces 0.03
- lib/Text/Replace.pm                                          1.1     2003/09/19 revised 1.09
- t/Text/Replace.t                                             0.04    2003/09/15 unchanged
- t/Text/Replace.pm                                            0.01    2003/07/05 unchanged
- t/Text/Replace.d                                             0.01    2003/07/27 unchanged
- tlib/File/Package.pm                                         1.12    2003/09/19 unchanged
- tlib/Test/Tech.pm                                            1.14    2003/09/19 revised 1.13
- tlib/Data/Secs2.pm                                           1.14    2003/09/19 new
+ lib/Docs/Site_SVD/Text_Replace.pm                            0.05    2004/05/04 revised 0.04
+ MANIFEST                                                     0.05    2004/05/04 generated, replaces 0.04
+ Makefile.PL                                                  0.05    2004/05/04 generated, replaces 0.04
+ README                                                       0.05    2004/05/04 generated, replaces 0.04
+ lib/Text/Replace.pm                                          1.11    2004/05/04 revised 1.1
+ t/Text/Replace.t                                             0.05    2004/05/04 revised 0.04
+ t/Text/Replace.pm                                            0.03    2004/05/04 revised 0.02
+ t/Text/Replace.d                                             0.04    2004/05/04 revised 0.03
+ t/Text/File/Package.pm                                       1.16    2004/05/04 new
+ t/Text/Test/Tech.pm                                          1.22    2004/05/04 new
+ t/Text/Data/Secs2.pm                                         1.19    2004/05/04 new
+ t/Text/Data/SecsPack.pm                                      0.04    2004/05/04 new
+ t/Text/Data/Startup.pm                                       0.04    2004/05/04 new
 
 
 =head2 3.3 Changes
@@ -266,6 +269,18 @@ a directory with mode of 666.
 Add the module 'Data::Secs2' in the tlib that provides 'stringify' support
 for the 'Test::Tech' module.
 
+=item Text-Column-0.05
+
+The lastest build of C<Test::STDmaker> expects the test library in the same
+directory as the test script.
+Coordiated with the lastest Test::STDmaker by moving the
+test library from tlib to t/Text, the same directory as the test script
+and deleting the test library C<File::TestPath> program module,
+adding the C<Data::SecsPack> and C<Data::Startup> to the test library.
+
+Added Description, Subroutines, See Also headers. 
+Clean up the Quality Assurance and Notes.
+
 =back
 
 =head2 3.4 Adaptation data.
@@ -290,18 +305,36 @@ and installation support are as follows:
 
 =item Installation Instructions.
 
-To installed the release file, use the CPAN module in the Perl release
+To installed the release file, use the CPAN module
+pr PPM module in the Perl release
 or the INSTALL.PL script at the following web site:
 
  http://packages.SoftwareDiamonds.com
 
 Follow the instructions for the the chosen installation software.
 
-The distribution file is at the following respositories:
+If all else fails, the file may be manually installed.
+Enter one of the following repositories in a web browser:
 
-   http://www.softwarediamonds/packages/Text-Replace-0.04
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Text-Replace-0.04
+  http://www.softwarediamonds/packages/
+  http://www.perl.com/CPAN/authors/id/S/SO/SOFTDIA/
 
+Right click on 'Text-Replace-0.05.tar.gz' and download to a temporary
+installation directory.
+Enter the following where $make is 'nmake' for microsoft
+windows; otherwise 'make'.
+
+ gunzip Text-Replace-0.05.tar.gz
+ tar -xf Text-Replace-0.05.tar
+ perl Makefile.PL
+ $make test
+ $make install
+
+On Microsoft operating system, nmake, tar, and gunzip 
+must be in the exeuction path. If tar and gunzip are
+not install, download and install unxutils from
+
+ http://packages.softwarediamonds.com
 
 =item Prerequistes.
 
@@ -341,24 +374,6 @@ State the functional requirements for each method
 including not only the GO paths but also what to
 expect for the NOGO paths
 
-=item *
-
-All the tests are GO path tests. Should add
-NOGO tests.
-
-=item *
-
-Add the requirements addressed as I<# R: >
-comment to the tests
-
-=item *
-
-Write a program to build a matrix to trace
-test step to the requirements and vice versa by
-parsing the I<# R: > comments.
-Automatically insert the matrix in the
-Test::TestUtil POD.
-
 =back
 
 =head1 4.0 NOTES
@@ -389,23 +404,12 @@ extension for a Perl test script file
 
 =item L<Docs::US_DOD::SVD|Docs::US_DOD::SVD> 
 
+=item L<Template|Template> 
+
 =back
 
 =for html
-<hr>
-<p><br>
-<!-- BLK ID="PROJECT_MANAGEMENT" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="NOTICE" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="OPT-IN" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="LOG_CGI" -->
-<!-- /BLK -->
-<p><br>
+
 
 =cut
 
@@ -416,11 +420,11 @@ __DATA__
 DISTNAME: Text-Replace^
 REPOSITORY_DIR: packages^
 
-VERSION : 0.04^
+VERSION : 0.05^
 FREEZE: 1^
 PREVIOUS_DISTNAME:  ^
-PREVIOUS_RELEASE: 0.03^
-REVISION: C^
+PREVIOUS_RELEASE: 0.04^
+REVISION: D^
 
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
 ABSTRACT: Replace variables in templates^
@@ -434,7 +438,7 @@ SVD_FSPEC: Unix^
 
 REPOSITORY: 
   http://www.softwarediamonds/packages/
-  http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/
+  http://www.perl.com/CPAN/authors/id/S/SO/SOFTDIA/
 ^
 
 COMPRESS: gzip^
@@ -448,11 +452,15 @@ lib/Text/Replace.pm
 t/Text/Replace.t
 t/Text/Replace.pm
 t/Text/Replace.d
-lib/File/Package.pm => tlib/File/Package.pm
-lib/Test/Tech.pm => tlib/Test/Tech.pm
-lib/Data/Secs2.pm => tlib/Data/Secs2.pm
+lib/File/Package.pm => t/Text/File/Package.pm
+lib/Test/Tech.pm => t/Text/Test/Tech.pm
+lib/Data/Secs2.pm => t/Text/Data/Secs2.pm
+lib/Data/SecsPack.pm => t/Text/Data/SecsPack.pm
+lib/Data/Startup.pm => t/Text/Data/Startup.pm
 ^
 
+PREREQ_PM:  ^
+README_PODS: lib/Text/Replace.pm^
 TESTS: t/Text/Replace.t^
 EXE_FILES:  ^
 
@@ -515,6 +523,18 @@ a directory with mode of 666.
 Add the module 'Data::Secs2' in the tlib that provides 'stringify' support
 for the 'Test::Tech' module.
 
+\=item Text-Column-0.05
+
+The lastest build of C<Test::STDmaker> expects the test library in the same
+directory as the test script.
+Coordiated with the lastest Test::STDmaker by moving the
+test library from tlib to t/Text, the same directory as the test script
+and deleting the test library C<File::TestPath> program module,
+adding the C<Data::SecsPack> and C<Data::Startup> to the test library.
+
+Added Description, Subroutines, See Also headers. 
+Clean up the Quality Assurance and Notes.
+
 \=back
 
 ^
@@ -527,30 +547,27 @@ utilize and track this release.
 ^
 
 CAPABILITIES:
-The "L<Text::Replace|Text::Replace>" module, 
-extends the Perl language (the system).
+The C<Text::Replace> program module is simple and plain. 
+This is intentional. The C<Text::Replace> mimics the
+built-in Perl double quote, '"', literal scalar that
+replaces Perl scalar variables named with a leading '$'.
+The C<Text::Replace> program module foregoes 
+expressiveness for convenience and performance.
+Like a movie score, it stays in the background.
+There is no large manual thicker than the Bible 
+with tricks and tips and gyrations to learn and 
+to distract.
+It is amazing how many times, just a simple double quote
+literal replacement in a small text string or even a
+large text string gets the job done.
 
-The US DOD 2167A software development standard creates and cites a
-fully decent number of Data Item Descriptions (DID). 
-A DID and US DOD 490A, Specification Practices, specify in
-great detail the paragraph number, headings and the information
-required for each paragraph in the document govern by the DID.
-
-The usually approach is for suppliers of the DIDs to set up templates
-and fill in the template with the missing information to complete the
-DID document.
-
-Different organizations use different degrees of automation. 
-Some will have hard copy templates. Some will use word processor
-templates. Others will use Visual Basic to merge database information
-into a template. 
-
-The methods in this module support a Perl automation of this processes
-by merging a hash of variables with a template.
-
-Replacement of variables in a template has many others uses beside
-filling out technical document templates such as merging mailing list
-with emails or form letters.
+Does C<Text::Replace> solve all variable replacement, template
+problems? Definitely not.
+There is no capabilities for inserting graphs, text wrap plug-ins,
+GD interface.
+If an application needs something this sophisticated,
+there are many fine template program modules in CPAN
+such as the highly rated C<Template> program module.
 ^
 
 PROBLEMS:
@@ -565,24 +582,6 @@ State the functional requirements for each method
 including not only the GO paths but also what to
 expect for the NOGO paths
 
-\=item *
-
-All the tests are GO path tests. Should add
-NOGO tests.
-
-\=item *
-
-Add the requirements addressed as I<# R: >
-comment to the tests
-
-\=item *
-
-Write a program to build a matrix to trace
-test step to the requirements and vice versa by
-parsing the I<# R: > comments.
-Automatically insert the matrix in the
-Test::TestUtil POD.
-
 \=back
 
 ^
@@ -632,19 +631,39 @@ ANY WAY OUT OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 INSTALLATION:
-To installed the release file, use the CPAN module in the Perl release
+To installed the release file, use the CPAN module
+pr PPM module in the Perl release
 or the INSTALL.PL script at the following web site:
 
  http://packages.SoftwareDiamonds.com
 
 Follow the instructions for the the chosen installation software.
 
-The distribution file is at the following respositories:
+If all else fails, the file may be manually installed.
+Enter one of the following repositories in a web browser:
 
 ${REPOSITORY}
+
+Right click on '${DIST_FILE}' and download to a temporary
+installation directory.
+Enter the following where $make is 'nmake' for microsoft
+windows; otherwise 'make'.
+
+ gunzip ${BASE_DIST_FILE}.tar.${COMPRESS_SUFFIX}
+ tar -xf ${BASE_DIST_FILE}.tar
+ perl Makefile.PL
+ $make test
+ $make install
+
+On Microsoft operating system, nmake, tar, and gunzip 
+must be in the exeuction path. If tar and gunzip are
+not install, download and install unxutils from
+
+ http://packages.softwarediamonds.com
 ^
 
-SUPPORT: 603 882-0846 E<lt>support@SoftwareDiamonds.comE<gt>^
+SUPPORT: 603 882-0846 E<lt>support@SoftwareDiamonds.comE<gt>
+^
 
 NOTES:
 The following are useful acronyms:
@@ -674,24 +693,13 @@ SEE_ALSO:
 
 \=item L<Docs::US_DOD::SVD|Docs::US_DOD::SVD> 
 
+\=item L<Template|Template> 
+
 \=back
 ^
 
 HTML:
-<hr>
-<p><br>
-<!-- BLK ID="PROJECT_MANAGEMENT" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="NOTICE" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="OPT-IN" -->
-<!-- /BLK -->
-<p><br>
-<!-- BLK ID="LOG_CGI" -->
-<!-- /BLK -->
-<p><br>
+
 ^
 ~-~
 
